'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = injectRuleByLookup;
/**
 * @copyright   2017, Miles Johnson
 * @license     https://opensource.org/licenses/MIT
 * 
 */

/*:: import type { AtRuleMap, AtRuleCache, CSSStyle } from '../../types';*/
function injectRuleByLookup(properties /*: CSSStyle*/, propName /*: string*/, lookup /*: AtRuleMap | AtRuleCache*/) {
  var flatten /*: boolean*/ = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;

  var value = properties[propName];

  if (typeof value !== 'string') {
    return;
  }

  value = value.split(',').map(function (name /*: string*/) {
    name = name.trim();
    var found = lookup[name];

    if (found && Array.isArray(found)) {
      found = found[0];
    }

    return found || name;
  });

  if (flatten) {
    value = value.join(', ');
  } else if (value.length === 1) {
    value = value[0];
  }

  properties[propName] = value;
}